Deletes all locally cached ECB data files. The next call to any data function will re-download from the ECB Data Portal.
See also
Other data access:
ecb_get(),
ecb_yield_curve(),
list_ecb_dataflows()
Deletes all locally cached ECB data files. The next call to any data function will re-download from the ECB Data Portal.
Other data access:
ecb_get(),
ecb_yield_curve(),
list_ecb_dataflows()