Skip to contents

Returns EURIBOR (Euro Interbank Offered Rate) at one or more tenors. EURIBOR is the benchmark rate at which euro area banks lend to each other, widely used as a reference rate for mortgages, loans, and derivatives.

Usage

ecb_euribor(tenor = "3M", from = NULL, to = NULL, cache = TRUE)

Arguments

tenor

One or more of "1M" (1 month), "3M" (default), "6M", or "12M".

from

Optional start date.

to

Optional end date.

cache

Logical. Use cached data if available (default TRUE).

Value

A data frame with columns:

date

Date.

tenor

Character. EURIBOR maturity.

value

Numeric. Rate in percent per annum.

See also

Other interest rates: ecb_estr(), ecb_policy_rates()

Examples

# \donttest{
op <- options(readecb.cache_dir = tempdir())
try({
  ecb_euribor("3M", from = "2022-01")
  ecb_euribor(c("1M", "3M", "6M", "12M"), from = "2024-01")
})
#> ℹ Fetching EURIBOR data
#> ✔ Fetching EURIBOR data [1.4s]
#> 
#> ℹ Fetching EURIBOR data
#> ✔ Fetching EURIBOR data [1.1s]
#> 
#>           date tenor    value
#> 1   2024-01-01   12M 3.609227
#> 2   2024-02-01   12M 3.670524
#> 3   2024-03-01   12M 3.717850
#> 4   2024-04-01   12M 3.703333
#> 5   2024-05-01   12M 3.680136
#> 6   2024-06-01   12M 3.649600
#> 7   2024-07-01   12M 3.525913
#> 8   2024-08-01   12M 3.166136
#> 9   2024-09-01   12M 2.936048
#> 10  2024-10-01   12M 2.691304
#> 11  2024-11-01   12M 2.505571
#> 12  2024-12-01   12M 2.436050
#> 13  2025-01-01   12M 2.525227
#> 14  2025-02-01   12M 2.406950
#> 15  2025-03-01   12M 2.398381
#> 16  2025-04-01   12M 2.143400
#> 17  2025-05-01   12M 2.080571
#> 18  2025-06-01   12M 2.080905
#> 19  2025-07-01   12M 2.079087
#> 20  2025-08-01   12M 2.113905
#> 21  2025-09-01   12M 2.171500
#> 22  2025-10-01   12M 2.187304
#> 23  2025-11-01   12M 2.216900
#> 24  2025-12-01   12M 2.267143
#> 25  2026-01-01   12M 2.245095
#> 26  2026-02-01   12M 2.220700
#> 27  2026-03-01   12M 2.565136
#> 28  2026-04-01   12M 2.746800
#> 29  2026-05-01   12M 2.804200
#> 30  2026-06-01   12M 2.797591
#> 31  2026-07-01   12M 2.855087
#> 32  2026-08-01   12M 2.953667
#> 33  2024-01-01    1M 3.869000
#> 34  2024-02-01    1M 3.868476
#> 35  2024-03-01    1M 3.852950
#> 36  2024-04-01    1M 3.852524
#> 37  2024-05-01    1M 3.815909
#> 38  2024-06-01    1M 3.634700
#> 39  2024-07-01    1M 3.617522
#> 40  2024-08-01    1M 3.596727
#> 41  2024-09-01    1M 3.438095
#> 42  2024-10-01    1M 3.205478
#> 43  2024-11-01    1M 3.066429
#> 44  2024-12-01    1M 2.890050
#> 45  2025-01-01    1M 2.791864
#> 46  2025-02-01    1M 2.605750
#> 47  2025-03-01    1M 2.401000
#> 48  2025-04-01    1M 2.242650
#> 49  2025-05-01    1M 2.093905
#> 50  2025-06-01    1M 1.928524
#> 51  2025-07-01    1M 1.892261
#> 52  2025-08-01    1M 1.890000
#> 53  2025-09-01    1M 1.897227
#> 54  2025-10-01    1M 1.906261
#> 55  2025-11-01    1M 1.905600
#> 56  2025-12-01    1M 1.915476
#> 57  2026-01-01    1M 1.960762
#> 58  2026-02-01    1M 1.952250
#> 59  2026-03-01    1M 1.932773
#> 60  2026-04-01    1M 1.971200
#> 61  2026-05-01    1M 1.956550
#> 62  2026-06-01    1M 2.146318
#> 63  2026-07-01    1M 2.214043
#> 64  2026-08-01    1M 2.220952
#> 65  2024-01-01    3M 3.925273
#> 66  2024-02-01    3M 3.923191
#> 67  2024-03-01    3M 3.923100
#> 68  2024-04-01    3M 3.885333
#> 69  2024-05-01    3M 3.812682
#> 70  2024-06-01    3M 3.724500
#> 71  2024-07-01    3M 3.684826
#> 72  2024-08-01    3M 3.547591
#> 73  2024-09-01    3M 3.433714
#> 74  2024-10-01    3M 3.166609
#> 75  2024-11-01    3M 3.006762
#> 76  2024-12-01    3M 2.824600
#> 77  2025-01-01    3M 2.704273
#> 78  2025-02-01    3M 2.524950
#> 79  2025-03-01    3M 2.442429
#> 80  2025-04-01    3M 2.249400
#> 81  2025-05-01    3M 2.087238
#> 82  2025-06-01    3M 1.983619
#> 83  2025-07-01    3M 1.986348
#> 84  2025-08-01    3M 2.021095
#> 85  2025-09-01    3M 2.027273
#> 86  2025-10-01    3M 2.034435
#> 87  2025-11-01    3M 2.041650
#> 88  2025-12-01    3M 2.048429
#> 89  2026-01-01    3M 2.027727
#> 90  2026-02-01    3M 2.011300
#> 91  2026-03-01    3M 2.109409
#> 92  2026-04-01    3M 2.175300
#> 93  2026-05-01    3M 2.226100
#> 94  2026-06-01    3M 2.339000
#> 95  2026-07-01    3M 2.425391
#> 96  2026-08-01    3M 2.513143
#> 97  2024-01-01    6M 3.891682
#> 98  2024-02-01    6M 3.900524
#> 99  2024-03-01    6M 3.894800
#> 100 2024-04-01    6M 3.838238
#> 101 2024-05-01    6M 3.786636
#> 102 2024-06-01    6M 3.714900
#> 103 2024-07-01    6M 3.643565
#> 104 2024-08-01    6M 3.424909
#> 105 2024-09-01    6M 3.257810
#> 106 2024-10-01    6M 3.001609
#> 107 2024-11-01    6M 2.787524
#> 108 2024-12-01    6M 2.632150
#> 109 2025-01-01    6M 2.614409
#> 110 2025-02-01    6M 2.459600
#> 111 2025-03-01    6M 2.385381
#> 112 2025-04-01    6M 2.201700
#> 113 2025-05-01    6M 2.116191
#> 114 2025-06-01    6M 2.049667
#> 115 2025-07-01    6M 2.055348
#> 116 2025-08-01    6M 2.084429
#> 117 2025-09-01    6M 2.102318
#> 118 2025-10-01    6M 2.106826
#> 119 2025-11-01    6M 2.131000
#> 120 2025-12-01    6M 2.139476
#> 121 2026-01-01    6M 2.137143
#> 122 2026-02-01    6M 2.143500
#> 123 2026-03-01    6M 2.321954
#> 124 2026-04-01    6M 2.453750
#> 125 2026-05-01    6M 2.536400
#> 126 2026-06-01    6M 2.595500
#> 127 2026-07-01    6M 2.646739
#> 128 2026-08-01    6M 2.713333
options(op)
# }