Returns outstanding amounts for M1, M2, or M3 monetary aggregates in the euro area.
Usage
ecb_money_supply(
aggregate = c("M3", "M2", "M1"),
from = NULL,
to = NULL,
cache = TRUE
)See also
Other credit:
ecb_lending_rates(),
ecb_mortgage_rates()
Examples
# \donttest{
op <- options(readecb.cache_dir = tempdir())
try({
ecb_money_supply("M3", from = "2020-01")
})
#> ℹ Fetching M3 data
#> ✖ Fetching M3 data [30.1s]
#>
#> Error in ecb_fetch("BSI", key, from = from, to = to, cache = cache) :
#> The ECB Data Portal returned a web page rather than data (HTTP 504).
#> ℹ This usually means the service is temporarily unavailable or under
#> maintenance, rather than that the query is wrong.
#> ℹ Dataflow "BSI", key "M.U2.N.V.M30.X.1.U2.2300.Z01.E".
options(op)
# }